@@ -72,11 +72,8 @@ Classes & Functions
 import requests
 import numpy as np
 
-from .proplist import prop2abr, abr2prop, abr2key, properties
+from .proplist import prop2key, prop2abr, abr2prop, abr2key, properties
 from .version import __version__
-#JOAO
-from proplist import prop2key
-#JOAO
 
 __license__   = "MIT"
 __docformat__ = 'reStructuredText'
